%define module	sympy

Summary:	Python library for symbolic mathematics
Name:		python-%{module}
Version:	0.7.3
Release:	%mkrel 4
Source0:	https://github.com/%{module}/%{module}/releases/download/%{module}-%{version}/%{module}-%{version}.tar.gz
Source1:	https://github.com/%{module}/%{module}/releases/download/%{module}-%{version}/%{module}-%{version}-py3.3.tar.gz
Patch0:		sympy-0.7.3-strip-internal-mpmath.patch
License:	BSD
Group:		Development/Python
Url:		http://sympy.googlecode.com/
Requires: 	python-numpy
Requires:	python-mpmath
Requires:	python-matplotlib
Suggests:	python-gmpy >= 1.03, python-pyglet
BuildRequires:	python-devel
BuildRequires:	python-sphinx
BuildRequires:	python-mpmath
BuildArch:	noarch

%description
SymPy is a Python library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python and does not require
any external libraries, except optionally for plotting support.

%package texmacs
Summary:        TeXmacs integration for sympy
Group:		Development/Python
Requires:       %{name} = %{version}-%{release}, TeXmacs

%description texmacs
This package contains a TeXmacs plugin for sympy.

%package examples
Summary:        Sympy examples
Group:		Development/Python
Requires:       %{name} = %{version}-%{release}

%description examples
This package contains example input for sympy.

%package doc
Summary:        Documentation for sympy
Group:		Development/Python

%description doc
man  and HTML documentation for sympy.

%package -n python3-%{module}
Summary:        Python 3 library for symbolic mathematics
Group:		Development/Python
BuildRequires:	python3-devel
BuildRequires:	python3-mpmath
Requires: 	python3-numpy
Requires:	python3-mpmath
Requires:	python3-matplotlib

%description -n python3-%{module}
SymPy is a Python 3 library for symbolic mathematics. It aims to become
a full-featured computer algebra system (CAS) while keeping the code
as simple as possible in order to be comprehensible and easily
extensible. SymPy is written entirely in Python 3 and does not require
any external libraries, except optionally for plotting support.

%prep
%setup -q -n %{module}-%{version}
%patch0 -b .mpmath
rm -rf sympy/mpmath doc/src/modules/mpmath
mkdir %{py3dir} 
pushd %{py3dir}
gzip -dc %{SOURCE1} | tar -xvvf -
popd

%build
%{__python} setup.py build

pushd doc
make html
popd

pushd %{py3dir}/%{module}-%{version} 
rm sympy/mpmath/libmp/exec_py2.py
%{__python3} setup.py build
popd

%install
pushd %{py3dir}/%{module}-%{version} 
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}
mv %{buildroot}%{_bindir}/isympy %{buildroot}%{_bindir}/python3-isympy
popd

%{__python} setup.py install -O1 --skip-build --root %{buildroot}
# Remove extra files
rm -f %{buildroot}%{_bindir}/{,doc}test

# Install the TeXmacs integration
cp -p data/TeXmacs/bin/tm_sympy %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/TeXmacs/plugins/sympy
cp -a data/TeXmacs/progs %{buildroot}%{_datadir}/TeXmacs/plugins/sympy

# Don't let an executable script go into the documentation
chmod a-x examples/all.py

# Install the HTML documentation
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
cp -a doc/_build/html %{buildroot}%{_docdir}/%{name}-doc
rm -f %{buildroot}%{_docdir}/%{name}-doc/html/.buildinfo
rm -fr %{buildroot}%{_docdir}/%{name}-doc/i18n

%files
%doc AUTHORS LICENSE PKG-INFO 
%{python_sitelib}/sympy/
%{python_sitelib}/sympy-%{version}-*.egg-info
%{_bindir}/isympy

%files texmacs
%doc data/TeXmacs/LICENSE
%{_bindir}/tm_sympy
%{_datadir}/TeXmacs/plugins/sympy/

%files examples
%doc examples

%files doc
%docdir %{_docdir}/%{name}-doc/html
%{_docdir}/%{name}-doc/html
%{_mandir}/man1/isympy.1*

%files -n python3-%{module}
%doc AUTHORS LICENSE PKG-INFO 
%{python3_sitelib}/sympy/
%{python3_sitelib}/sympy-%{version}-*.egg-info
%{_bindir}/python3-isympy



%changelog
* Fri Nov 22 2013 philippem <philippem> 0.7.3-4.mga4
+ Revision: 552336
- add missing requires python-mpmath and python-matplotlib fix mga#11736

* Tue Oct 22 2013 umeabot <umeabot> 0.7.3-3.mga4
+ Revision: 544340
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.7.3-2.mga4
+ Revision: 499514
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Oct 03 2013 philippem <philippem> 0.7.3-1.mga4
+ Revision: 490623
-update to 0.7.3
- add Python 3
- split doc , examples and texmacs in subpackages

* Sun Jan 13 2013 umeabot <umeabot> 0.7.1-2.mga3
+ Revision: 379552
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Sep 20 2011 lebedov <lebedov> 0.7.1-1.mga2
+ Revision: 146159
- imported package python-sympy

